#!/bin/zsh

DRY_RUN=false

owner=pymc-labs
repo=pymc-marketing
issue_number=1556
title="Remove warnings in tests :warning:"
workflow=Test
latest_id=$(gh run list --workflow $workflow --status success --limit 1 --json databaseId --jq '.[0].databaseId')
jobs=$(gh api /repos/$owner/$repo/actions/runs/$latest_id/jobs --jq '.jobs | map({name: .name, run_id: .run_id, id: .id, started_at: .started_at, completed_at: .completed_at})')


all_warnings=""
echo "$jobs" | jq -c '.[]' | while read -r job; do
    id=$(echo $job | jq -r '.id')
    name=$(echo $job | jq -r '.name')
    run_id=$(echo $job | jq -r '.run_id')
    started_at=$(echo $job | jq -r '.started_at')
    completed_at=$(echo $job | jq -r '.completed_at')

    echo "Processing job: $name (ID: $id, Run ID: $run_id)"
    warnings=$(gh run view --job $id --log | python extract-warnings.py)
    echo $warnings

    top="<details><summary>$name</summary>\n\n\n\`\`\`"
    bottom="\`\`\`\n\n</details>"

    formatted_warnings="$top\n$warnings\n$bottom"

    if [ -n "$all_warnings" ]; then
        all_warnings="$all_warnings\n$formatted_warnings"
    else
        all_warnings="$formatted_warnings"
    fi
done

run_date=$(date +"%Y-%m-%d")
body=$(cat << EOF
If you are motivated to remove warnings from tests, we would appreciate it!

Here are warnings:

$all_warnings

> [!NOTE]
>
> Some warnings are out of our control, maybe they can be suppressed or ignored.

You can find more information on how to contribute [here](https://www.pymc-marketing.io/en/stable/contributing/index.html).

Automatically generated by [GitHub Action](https://github.com/pymc-labs/pymc-marketing/blob/main/.github/workflows/update-test-issues.yml)
Latest run date: $run_date
EOF
)

if [ "$DRY_RUN" = true ]; then
    echo "Dry run, not updating issue"
    echo $body
    exit
fi
echo $body
echo $body | gh issue edit $issue_number --body-file - --title "$title"
echo "Updated issue $issue_number with all warnings"
